import React from 'react'
import styled from 'styled-components'
import TabelaAnimadaDupla from '../components/TabelaAnimadaDupla'

const StyledDiv = styled.div`
td.linha1, td.linha2 {
  color: black;
}

ul {
  padding-left: 1.25em;
  margin-bottom: 0;
}

ul:first-child {
  margin-bottom: 1vh;
}

.table-container {
  margin-top: 2vh;
}
`

class Page extends React.Component {
  componentDidMount() {

  }

  render() {
    return (
      <StyledDiv className='content'>
        <h2>Síndromes tóxicas</h2>
        <div className='page'>
          <p>Com os dados de anamnese e exame físico, chegamos a um ponto importante na avaliação de um paciente vítima de intoxicação aguda: a classificação sindrômica. A classificação sindrômica se propõe a estabelecer, por meio dos sinais e sintomas identificados, os possíveis agentes envolvidos na intoxicação aguda. Para conhecer mais sobre cada síndrome tóxica, <strong>clique</strong> nos botões abaixo:</p>
          <div className="table-container">
            <TabelaAnimadaDupla Header={["Síndrome", "Agentes causadores e quando suspeitar"]} RowIndex={["Simpaticomimética", "Anticolinérgica", "Alucinógena", "Opioide", "Sedativo-hipnótica", "Colinérgica", "Serotoninérgica", "Antidepressivos tricíclicos"]} RowsContent={[
              [<ul>
                <li>Agentes causadores: cocaína, anfetaminas, efedrina, teofilina, cafeína.</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <ul>
                <li>Estado neurológico: habitualmente hiperalerta ou agitado; alucinações podem estar presentes; na avaliação pupilar pode haver midríase.</li>
                <li>Sinais vitais: temperatura, frequência cardíaca, pressão arterial e frequência respiratória podem estar elevadas.</li>
                <li>Outras manifestações: paranoia, diaforese, tremores de extremidades, hiperreflexia, convulsões.</li>
              </ul>],
              [<ul>
                <li>Agentes causadores: anti-histamínicos, ciclobenzaprina, antiparkinsonianos, antiespasmódicos, atropina, antidepressivos tricíclicos.</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <p>Uma boa forma de recordar é por meio do mnemônico baseado no livro: Alice’s Adventures in Wonderland, de Lewis Carroll: “Cego com um morcego, louco com um chapeleiro, vermelho como uma beterraba, quente como uma lebre e seco como um osso” (em tradução livre).</p>,
              <ul>
                <li>Estado neurológico: pode haver alucinações e agitação psicomotora, além de coma.</li>
                <li>Sinais vitais: também pode ocorrer elevação de temperatura, frequência cardíaca, pressão arterial e frequência respiratória.</li>
                <li>Outras manifestações: delírio, fala murmurante, pele e mucosas secas, retenção urinária, diminuição de ruídos hidroaéreos, mioclonia.</li>
              </ul>],
              [<ul>
                <li>Agentes causadores: fenciclidina, dietilamida do ácido lisérgico (LSD), mescalina.</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <ul>
                <li>Estado neurológico: presença de alucinações; midríase ocorre frequentemente.</li>
                <li>Sinais vitais: também há elevação dos parâmetros.</li>
                <li>Outras manifestações: distorção da percepção, despersonalização, sinestesia, nistagmo.</li>
              </ul>],
              [<ul>
                <li>Agentes envolvidos: morfina, meperidina, codeína, metadona, oxicodona.</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <ul>
                <li>Estado neurológico: depressão do sistema nervoso central, depressão respiratória, miose, coma.</li>
                <li>Sinais vitais: hipotensão, bradicardia e bradipneia podem ocorrer.</li>
                <li>Outras manifestações: hiporreflexia, edema pulmonar.</li>
              </ul>],
              [<ul>
                <li>Agentes envolvidos: benzodiazepínicos, barbitúricos, carisoprodol, zolpidem, álcool.</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <ul>
                <li>Estado neurológico: confusão, depressão do sistema nervoso central, miose, coma.</li>
                <li>Outras manifestações: hiporreflexia.</li>
              </ul>],
              [<ul>
                <li>Agentes envolvidos: inseticidas organofosforados, carmatos, nicotina, fisostigmina</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <ul>
                <li>Estado neurológico: confusão e coma, miose.</li>
                <li>Sinais vitais: bradicardia, pode haver queda ou aumento da pressão arterial e da frequência respiratória.</li>
                <li>Outras manifestações: salivação, incontinência fecal ou urinária, êmese, diaforese, cólicas intestinais, broncoconstrição, fasciculações musculares, fraqueza, convulsões.</li>
              </ul>],
              [<ul>
                <li>Agentes envolvidos: inibidores da monoamina oxidase ou em associação com inibidores seletivos da recaptação da serotonina, meperididina.</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <ul>
                <li>Estado neurológico: hiperalerta ou agitado, confusão, coma, midríase.</li>
                <li>Sinais vitais: elevação dos parâmetros de frequência cardíaca, pressão arterial, frequência respiratória e temperatura.</li>
                <li>Outras manifestações: tremor, mioclonia, hiperreflexia, diaforese, rubor, trismo, rigidez e diarreia.</li>
              </ul>],
              [<ul>
                <li>Agentes envolvidos: amitriptilina, nortriptilina, imipramina, clomipramina.</li>
              </ul>,
              <p>Quando suspeitar?</p>,
              <ul>
                <li>Estado neurológico: hiperalerta ou agitado, confusões, coma, midríase.</li>
                <li>Sinais vitais: elevação de temperatura e frequência cardíaca, pode haver elevação da pressão arterial seguida de hipotensão e bradipneia.</li>
                <li>Outras manifestações: convulsões, mioclonias, arritmias cardíacas e distúrbios de condução.</li>
              </ul>]
            ]} />
          </div>
        </div>
      </StyledDiv >
    )
  }
}
export default Page
